===============
Module Contents
===============

This documentation is automatically generated by scanning all the source code. Parts
may be incomplete.

.. automodule:: pybdsim
    :members:
    :undoc-members:
    :show-inheritance:


pybdsim.Beam module
-------------------

.. automodule:: pybdsim.Beam
    :members:
    :undoc-members:
    :show-inheritance:

pybdsim.Builder module
----------------------

.. automodule:: pybdsim.Builder
                :members:
		:undoc-members:
		:show-inheritance:	


pybdsim.Compare
---------------

.. automodule:: pybdsim.Compare
		:members:
		:undoc-members:

		.. autofunction:: MadxVsBDSIM
		.. autofunction:: MadxVsBDSIMOrbit
		.. autofunction:: BDSIMVsBDSIM
		.. autofunction:: TransportVsBDSIM 


pybdsim.Constants module
------------------------

.. automodule:: pybdsim.Constants
		:members:
		:undoc-members:
		:show-inheritance:

.. _pybdsim-convert:

pybdsim.Convert
---------------

.. automodule:: pybdsim.Convert
		:members:
		:undoc-members:

		.. autofunction:: BdsimPrimaries2Mad8
		.. autofunction:: BdsimPrimaries2Madx
		.. autofunction:: BdsimPrimaries2Ptc
		.. autofunction:: MadxTfs2Gmad
		.. autofunction:: MadxTfs2GmadStrength
				  

.. automodule:: pybdsim.Convert._MadxTfs2Gmad
		:members:

.. _pybdsim-data-module:
		   
pybdsim.Data module
-------------------

.. automodule:: pybdsim.Data
		:members:
		:undoc-members:
		:show-inheritance:


.. _pybdsim-field-module:

pybdsim.Field module
--------------------

.. automodule:: pybdsim.Field
		:members:
		:undoc-members:
		:show-inheritance:

.. automodule:: pybdsim.Field._Field
		:members:
		:show-inheritance:

.. automodule:: pybdsim.Field.FieldPlotter
		:members:


pybdsim.Gmad module
-------------------

.. automodule:: pybdsim.Gmad
		:members:
		:undoc-members:
		:show-inheritance:

pybdsim.ModelProcessing module
------------------------------

.. automodule:: pybdsim.ModelProcessing
		:members:
		:undoc-members:
		:show-inheritance:

.. _pybdsim-options-module:

pybdsim.Options module
----------------------

.. automodule:: pybdsim.Options
		:members:
		:undoc-members:
		:show-inheritance:

pybdsim.Plot module
-------------------

.. automodule:: pybdsim.Plot
		:members:
		:undoc-members:
		:show-inheritance:

pybdsim.Run module
------------------

.. automodule:: pybdsim.Run
		:members:
		:undoc-members:
		:show-inheritance:
		   
pybdsim.Visualisation module
----------------------------

.. automodule:: pybdsim.Visualisation
		:members:
		:undoc-members:
		:show-inheritance:

pybdsim.Writer module
---------------------

.. automodule:: pybdsim.Writer
		:members:
		:undoc-members:
		:show-inheritance:

.. _pybdsim-xsecbias-module:
		   
pybdsim.XSecBias module
-----------------------

.. automodule:: pybdsim.XSecBias
		:members:
		:undoc-members:
		:show-inheritance:
